@@ -38,7 +38,10 @@ LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 """
-from xmlrpclib import Fault
+try:
+    from xmlrpc.client import Fault
+except ImportError:  # Python 2
+    from xmlrpclib import Fault
 from django.contrib.auth import authenticate
 from django.utils.translation import gettext as _
 
@@ -57,7 +60,7 @@ class AuthenticationFailedException(Fault):
     """
     def __init__(self):
         Fault.__init__(self, AUTHENTICATION_FAILED_CODE,
-            _('Username and/or password is incorrect'))
+                       _('Username and/or password is incorrect'))
 
 
 class PermissionDeniedException(Fault):
@@ -92,16 +95,11 @@ def xmlrpc_method(returns='string', args=None, name=None):
         func
             The function to add the signature to
         """
-        # If name is not None, register the method with the dispatcher.
-        from django_xmlrpc.views import xmlrpcdispatcher
-        if name is not None:
-            xmlrpcdispatcher.register_function(func, name)
-
         # Add a signature to the function
         func._xmlrpc_signature = {
             'returns': returns,
             'args': args
-            }
+        }
         return func
 
     return _xmlrpc_func
@@ -167,8 +165,8 @@ def permission_required(perm=None):
             __authenticated_call.__doc__ = func.__doc__ + \
                 "\nNote: Authentication is required."""
             if perm:
-                __authenticated_call.__doc__ += ' this function requires ' \
-                                             + '"%s" permission.' % perm
+                __authenticated_call.__doc__ += (' this function requires '
+                                                 '"%s" permission.' % perm)
 
         return __authenticated_call
 
